@@ -662,15 +662,31 @@ fn func() -> ChainResult<(), FooError> {
 **/
 #[macro_export]
 macro_rules! cherr {
-    ( $k:expr ) => {
+    ( $k:expr ) => ({
         ChainError::<_>::new($k, None, Some((line!(), file!())))
-    };
-    ( None, $k:expr ) => {
+    });
+    ( None, $k:expr ) => ({
         ChainError::<_>::new($k, None, Some((line!(), file!())))
-    };
-    ( $e:expr, $k:expr ) => {
+    });
+    ( None, $fmt:expr, $($arg:tt)+ ) => ({
+        cherr!(None, format!($fmt, $($arg)+ ))
+    });
+    ( None, $fmt:expr, $($arg:tt)+ ) => ({
+        cherr!(None, format!($fmt, $($arg)+ ))
+    });
+    ( $e:ident, $k:expr ) => ({
         ChainError::<_>::new($k, Some(Box::from($e)), Some((line!(), file!())))
-    };
+    });
+    ( $e:path, $k:expr ) => ({
+        ChainError::<_>::new($k, Some(Box::from($e)), Some((line!(), file!())))
+    });
+    ( $e:ident, $fmt:expr, $($arg:tt)+ ) => ({
+        cherr!($e, format!($fmt, $($arg)+ ))
+    });
+    ( $e:path, $fmt:expr, $($arg:tt)+ ) => ({
+        cherr!($e, format!($fmt, $($arg)+ ))
+    });
+
 }
 
 /** convenience macro for |e| cherr!(e, format!(…))
@@ -768,6 +784,12 @@ macro_rules! mstrerr {
     ( $t:path, $msg:expr ) => ({
         |e| cherr!(e, $t ($msg.to_string()))
     });
+    ( $t:ident, $msg:expr, ) => ({
+        |e| cherr!(e, $t ($msg.to_string()))
+    });
+    ( $t:path, $msg:expr, ) => ({
+        |e| cherr!(e, $t ($msg.to_string()))
+    });
     ( $t:ident, $fmt:expr, $($arg:tt)+ ) => ({
         |e| cherr!(e, $t (format!($fmt, $($arg)+ )))
     });
@@ -828,6 +850,12 @@ macro_rules! strerr {
     ( $t:path, $msg:expr ) => ({
         cherr!($t ($msg.to_string()))
     });
+    ( $t:ident, $msg:expr, ) => ({
+        cherr!($t ($msg.to_string()))
+    });
+    ( $t:path, $msg:expr, ) => ({
+        cherr!($t ($msg.to_string()))
+    });
     ( $t:ident, $fmt:expr, $($arg:tt)+ ) => ({
         cherr!($t (format!($fmt, $($arg)+ )))
     });
